pub enum ChannelState {
Show 14 variants
Openingd,
ChanneldAwaitingLockin,
ChanneldNormal,
ChanneldShuttingDown,
ClosingdSigexchange,
ClosingdComplete,
AwaitingUnilateral,
FundingSpendSeen,
Onchain,
DualopendOpenInit,
DualopendAwaitingLockin,
DualopendOpenCommitted,
DualopendOpenCommitReady,
Unknown,
}Variants
Openingd
ChanneldAwaitingLockin
ChanneldNormal
ChanneldShuttingDown
ClosingdSigexchange
ClosingdComplete
AwaitingUnilateral
FundingSpendSeen
Onchain
DualopendOpenInit
DualopendAwaitingLockin
DualopendOpenCommitted
DualopendOpenCommitReady
Unknown
A state reported by the node that this SDK doesn’t recognize. Returned when CLN introduces a new channel state after this SDK was built. Treated as neither open nor closing by balance math.