pub enum SuccessActionProcessed {
Message {
message: String,
},
Url {
description: String,
url: String,
},
Aes {
description: String,
plaintext: String,
},
}Expand description
A processed success action from an LNURL-pay callback.
For Message and Url this is passed through as-is. For Aes the ciphertext has been decrypted using the payment preimage.
Variants
Message
Display a message to the user.
Url
Display a URL to the user.
Aes
Decrypted AES payload (LUD-10).