register

Function register 

pub fn register(
    mnemonic: String,
    invite_code: Option<String>,
    config: &Config,
) -> Result<Arc<Node>, Error>
Register a new Greenlight node and return a connected Node with signer running.

The app should call node.credentials() to get the credential bytes and persist them for future connect() calls.