pub struct Config { /* private fields */ }Implementations
Sourceimpl Config
impl Config
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a Config with default settings: BITCOIN network, no developer certificate.
Sourcepub fn with_developer_cert(&self, cert: &DeveloperCert) -> Arc<Config>
pub fn with_developer_cert(&self, cert: &DeveloperCert) -> Arc<Config>
Return a new Config with the given developer certificate. Nodes registered through this config will be associated with the developer’s account.
Sourcepub fn with_network(&self, network: Network) -> Arc<Config>
pub fn with_network(&self, network: Network) -> Arc<Config>
Return a new Config with the given network.