pub struct Credentials { /* private fields */ }Expand description
Credentials is a container for node_id, the mTLS client
certificate used to authenticate a client against a node, as well
as the seed secret if present. If no seed is present in the
credentials, then the Client will not start a signer in the
background.
Implementations