pub struct FundChannel {
pub peer_id: Vec<u8>,
pub our_amount_msat: u64,
pub amount_msat: u64,
pub funding_txid: Vec<u8>,
pub funding_output: u32,
pub connected: bool,
pub state: ChannelState,
pub short_channel_id: Option<String>,
pub channel_id: Option<Vec<u8>>,
}Fields
peer_id: Vec<u8>our_amount_msat: u64amount_msat: u64funding_txid: Vec<u8>funding_output: u32connected: boolstate: ChannelStateshort_channel_id: Option<String>channel_id: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for FundChannel
impl Clone for FundChannel
Sourcefn clone(&self) -> FundChannel
fn clone(&self) -> FundChannel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for FundChannel
impl<UT> ConvertError<UT> for FundChannel
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for FundChannel
impl<UT> FfiConverter<UT> for FundChannel
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ListfundsChannels> for FundChannel
impl From<ListfundsChannels> for FundChannel
Sourcefn from(other: ListfundsChannels) -> Self
fn from(other: ListfundsChannels) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for FundChannel
impl<UT> Lift<UT> for FundChannel
Sourceimpl<UT> LiftRef<UT> for FundChannel
impl<UT> LiftRef<UT> for FundChannel
type LiftType = FundChannel
Sourceimpl<UT> LiftReturn<UT> for FundChannel
impl<UT> LiftReturn<UT> for FundChannel
Sourcetype ReturnType = <FundChannel as Lift<UT>>::FfiType
type ReturnType = <FundChannel as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for FundChannel
impl<UT> Lower<UT> for FundChannel
type FfiType = <FundChannel as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for FundChannel
impl<UT> LowerError<UT> for FundChannel
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for FundChannel
impl<UT> LowerReturn<UT> for FundChannel
Sourcetype ReturnType = <FundChannel as Lower<UT>>::FfiType
type ReturnType = <FundChannel as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for FundChannel
impl<UT> TypeId<UT> for FundChannel