pub struct GetInfoResponse {
pub id: String,
pub alias: Option<String>,
pub color: String,
pub num_peers: u32,
pub num_pending_channels: u32,
pub num_active_channels: u32,
pub num_inactive_channels: u32,
pub version: String,
pub lightning_dir: String,
pub blockheight: u32,
pub network: String,
pub fees_collected_msat: u64,
}Fields
id: StringNode public key as lowercase hex (66 chars).
alias: Option<String>color: String3-byte RGB color as lowercase hex (6 chars).
num_peers: u32num_pending_channels: u32num_active_channels: u32num_inactive_channels: u32version: Stringlightning_dir: Stringblockheight: u32network: Stringfees_collected_msat: u64Trait Implementations
Sourceimpl Clone for GetInfoResponse
impl Clone for GetInfoResponse
Sourcefn clone(&self) -> GetInfoResponse
fn clone(&self) -> GetInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for GetInfoResponse
impl<UT> ConvertError<UT> for GetInfoResponse
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for GetInfoResponse
impl<UT> FfiConverter<UT> for GetInfoResponse
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<GetinfoResponse> for GetInfoResponse
impl From<GetinfoResponse> for GetInfoResponse
Sourcefn from(other: GetinfoResponse) -> Self
fn from(other: GetinfoResponse) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for GetInfoResponse
impl<UT> Lift<UT> for GetInfoResponse
Sourceimpl<UT> LiftRef<UT> for GetInfoResponse
impl<UT> LiftRef<UT> for GetInfoResponse
type LiftType = GetInfoResponse
Sourceimpl<UT> LiftReturn<UT> for GetInfoResponse
impl<UT> LiftReturn<UT> for GetInfoResponse
Sourcetype ReturnType = <GetInfoResponse as Lift<UT>>::FfiType
type ReturnType = <GetInfoResponse as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for GetInfoResponse
impl<UT> Lower<UT> for GetInfoResponse
type FfiType = <GetInfoResponse as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for GetInfoResponse
impl<UT> LowerError<UT> for GetInfoResponse
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for GetInfoResponse
impl<UT> LowerReturn<UT> for GetInfoResponse
Sourcetype ReturnType = <GetInfoResponse as Lower<UT>>::FfiType
type ReturnType = <GetInfoResponse as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl Serialize for GetInfoResponse
impl Serialize for GetInfoResponse
Sourceimpl<UT> TypeId<UT> for GetInfoResponse
impl<UT> TypeId<UT> for GetInfoResponse