pub struct Handle { /* private fields */ }Expand description
A handle to interact with a signer loop running and processing requests in the background. Used primarily to stop the loop and exiting the signer.
Implementations