pub struct Invoice {
pub label: String,
pub description: String,
pub payment_hash: Vec<u8>,
pub status: InvoiceStatus,
pub amount_msat: Option<u64>,
pub amount_received_msat: Option<u64>,
pub bolt11: Option<String>,
pub bolt12: Option<String>,
pub paid_at: Option<u64>,
pub expires_at: u64,
pub payment_preimage: Option<Vec<u8>>,
pub destination_pubkey: Option<Vec<u8>>,
}Fields
label: Stringdescription: Stringpayment_hash: Vec<u8>status: InvoiceStatusamount_msat: Option<u64>amount_received_msat: Option<u64>bolt11: Option<String>bolt12: Option<String>paid_at: Option<u64>expires_at: u64payment_preimage: Option<Vec<u8>>destination_pubkey: Option<Vec<u8>>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for Invoice
impl<UT> ConvertError<UT> for Invoice
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for Invoice
impl<UT> FfiConverter<UT> for Invoice
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ListinvoicesInvoices> for Invoice
impl From<ListinvoicesInvoices> for Invoice
Sourcefn from(other: ListinvoicesInvoices) -> Self
fn from(other: ListinvoicesInvoices) -> Self
Converts to this type from the input type.
Sourceimpl<UT> LiftReturn<UT> for Invoice
impl<UT> LiftReturn<UT> for Invoice
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for Invoice
impl<UT> LowerError<UT> for Invoice
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for Invoice
impl<UT> LowerReturn<UT> for Invoice
Sourcetype ReturnType = <Invoice as Lower<UT>>::FfiType
type ReturnType = <Invoice as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more