pub struct Pay {Show 13 fields
pub payment_hash: String,
pub status: PayStatus,
pub destination_pubkey: Option<String>,
pub amount_msat: Option<u64>,
pub amount_sent_msat: Option<u64>,
pub label: Option<String>,
pub bolt11: Option<String>,
pub description: Option<String>,
pub bolt12: Option<String>,
pub preimage: Option<String>,
pub created_at: u64,
pub completed_at: Option<u64>,
pub number_of_parts: Option<u64>,
}Fields
payment_hash: StringPayment hash as lowercase hex (64 chars).
status: PayStatusdestination_pubkey: Option<String>Recipient node pubkey as lowercase hex (66 chars), if known.
amount_msat: Option<u64>amount_sent_msat: Option<u64>label: Option<String>bolt11: Option<String>description: Option<String>bolt12: Option<String>preimage: Option<String>Payment preimage as lowercase hex (64 chars), if the payment completed.
created_at: u64completed_at: Option<u64>number_of_parts: Option<u64>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for Pay
impl<UT> ConvertError<UT> for Pay
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for Pay
impl<UT> FfiConverter<UT> for Pay
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ListpaysPays> for Pay
impl From<ListpaysPays> for Pay
Sourcefn from(other: ListpaysPays) -> Self
fn from(other: ListpaysPays) -> Self
Converts to this type from the input type.
Sourceimpl<UT> LiftReturn<UT> for Pay
impl<UT> LiftReturn<UT> for Pay
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for Pay
impl<UT> LowerError<UT> for Pay
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for Pay
impl<UT> LowerReturn<UT> for Pay
Sourcetype ReturnType = <Pay as Lower<UT>>::FfiType
type ReturnType = <Pay as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more