pub struct PeerChannel {
pub peer_id: Vec<u8>,
pub peer_connected: bool,
pub state: ChannelState,
pub short_channel_id: Option<String>,
pub channel_id: Option<Vec<u8>>,
pub funding_txid: Option<Vec<u8>>,
pub funding_outnum: Option<u32>,
pub to_us_msat: Option<u64>,
pub total_msat: Option<u64>,
pub spendable_msat: Option<u64>,
pub receivable_msat: Option<u64>,
}Fields
peer_id: Vec<u8>peer_connected: boolstate: ChannelStateshort_channel_id: Option<String>channel_id: Option<Vec<u8>>funding_txid: Option<Vec<u8>>funding_outnum: Option<u32>to_us_msat: Option<u64>total_msat: Option<u64>spendable_msat: Option<u64>receivable_msat: Option<u64>Trait Implementations
Sourceimpl Clone for PeerChannel
impl Clone for PeerChannel
Sourcefn clone(&self) -> PeerChannel
fn clone(&self) -> PeerChannel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for PeerChannel
impl<UT> ConvertError<UT> for PeerChannel
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for PeerChannel
impl<UT> FfiConverter<UT> for PeerChannel
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ListpeerchannelsChannels> for PeerChannel
impl From<ListpeerchannelsChannels> for PeerChannel
Sourcefn from(other: ListpeerchannelsChannels) -> Self
fn from(other: ListpeerchannelsChannels) -> Self
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for PeerChannel
impl<UT> Lift<UT> for PeerChannel
Sourceimpl<UT> LiftRef<UT> for PeerChannel
impl<UT> LiftRef<UT> for PeerChannel
type LiftType = PeerChannel
Sourceimpl<UT> LiftReturn<UT> for PeerChannel
impl<UT> LiftReturn<UT> for PeerChannel
Sourcetype ReturnType = <PeerChannel as Lift<UT>>::FfiType
type ReturnType = <PeerChannel as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for PeerChannel
impl<UT> Lower<UT> for PeerChannel
type FfiType = <PeerChannel as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for PeerChannel
impl<UT> LowerError<UT> for PeerChannel
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for PeerChannel
impl<UT> LowerReturn<UT> for PeerChannel
Sourcetype ReturnType = <PeerChannel as Lower<UT>>::FfiType
type ReturnType = <PeerChannel as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for PeerChannel
impl<UT> TypeId<UT> for PeerChannel