pub struct Scheduler { /* private fields */ }Implementations
Sourceimpl Scheduler
impl Scheduler
Sourcepub fn new(network: Network) -> Result<Scheduler, Error>
pub fn new(network: Network) -> Result<Scheduler, Error>
Create a Scheduler instance configured with the Greenlight
production service pre-configured.
Sourcepub fn with_developer_cert(&self, cert: &DeveloperCert) -> Scheduler
pub fn with_developer_cert(&self, cert: &DeveloperCert) -> Scheduler
Configure a developer certificate obtained from the Greenlight Developer Console. Nodes registered through this scheduler will be associated with the developer’s account.
Returns a new Scheduler instance with the developer
certificate configured.
pub fn register( &self, signer: &Signer, code: Option<String>, ) -> Result<Credentials, Error>
pub fn recover(&self, signer: &Signer) -> Result<Credentials, Error>