Crate glsdk

Crate glsdk 

Structs

Config
Credentials
Credentials is a container for node_id, the mTLS client certificate used to authenticate a client against a node, as well as the seed secret if present. If no seed is present in the credentials, then the Client will not start a signer in the background.
DeveloperCert
A developer certificate obtained from the Greenlight Developer Console (GDC). When provided to a Scheduler via with_developer_cert(), nodes registered through that scheduler will be associated with the developer’s account.
FundChannel
FundOutput
GetInfoResponse
Handle
A handle to interact with a signer loop running and processing requests in the background. Used primarily to stop the loop and exiting the signer.
Invoice
InvoicePaidEvent
Details of a paid invoice.
ListFundsResponse
ListInvoicesResponse
ListPaymentsRequest
ListPaysResponse
ListPeerChannelsResponse
ListPeersResponse
Node
The Node is an RPC stub representing the node running in the cloud. It is the main entrypoint to interact with the node.
NodeEventStream
A stream of node events. Call next() to receive the next event.
OnchainReceiveResponse
A pair of on-chain addresses for receiving funds.
OnchainSendResponse
Result of an on-chain send. The transaction has already been broadcast.
ParsedInvoice
Parsed BOLT11 invoice with extracted fields.
Pay
Payment
Peer
PeerChannel
ReceiveResponse
Scheduler
SendResponse
Signer

Enums

ChannelState
Error
InputType
The result of parsing user input.
InvoiceStatus
ListIndex
Index field used by CLN’s paginated list RPCs.
Network
NodeEvent
A real-time event from the node.
OutputStatus
PayStatus
PaymentStatus
PaymentType
PaymentTypeFilter

Functions

connect
Connect to an existing Greenlight node using previously saved credentials.
parse_input
Parse a string and identify whether it’s a BOLT11 invoice or a node ID.
recover
Recover credentials for an existing Greenlight node and return a connected Node.
register
Register a new Greenlight node and return a connected Node with signer running.
register_or_recover
Try to recover an existing node; if none exists, register a new one.